Aloha, World!

# Aloha, Images! (Extended Version :)

This extended example is intended for developers planning to use the the CropNResize plugin found at https://github.com/alohaeditor/Aloha-Plugin-CropNResize. It displays the whole set of configuration options currently available. Well, just take a look at the code.

Click the image to start resizing right away, as a resize handle will appear in it's south-east corner.